@@ -29,6 +29,7 @@ from calculate.lib.utils.ip import (getInterfaces, getIp, getMask, getMac,
                                     cidrToMask, maskToCidr, getIpNet, isDhcpIp,
                                     checkIp, checkMask, isSlaveInterface,
                                     getOperState, getPlugged)
+import calculate.lib.utils.device as device
 from calculate.lib.utils.device import lspci
 from calculate.lib.utils.files import (listDirectory, readLinesFile)
 from calculate.lib.utils import ip
@@ -233,8 +234,9 @@ class VariableOsInstallNetName(NetHelper, ReadonlyVariable):
         rePci = re.compile(r"(\d\d:\d\d\.\d)(?:/[^/]+){2}$")
 
         def getPci(interface):
-            pathname = path.realpath(path.join('/sys/class/net',
-                                               interface))
+            pathname = path.realpath(
+               device.sysfs.syspath(device.sysfs.Path.ClassNet, interface))
+            
             pci = rePci.search(pathname)
             if pci:
                 return pci.group(1)
